import { type CommentTag, type Context, DeclarationReflection, type DocumentReflection, ProjectReflection, ReflectionGroup } from "typedoc";
/**
 * Tries to determine the original name of a reflection.
 * @param context The TypeDoc context.
 * @param reflection The reflection whose original name is wanted.
 * @returns The original name of the reflection or undefined if it could not be determined.
 */
export declare function tryGetOriginalReflectionName(context: Readonly<Context>, reflection: DeclarationReflection): string | undefined;
/**
 * Removes a possible tag from the comments of the given reflection.
 * @param reflection The reflection from which the tag should be removed.
 * @param tagToRemove Name of the tag to be removed.
 */
export declare function removeTagFromCommentsOf(reflection: DeclarationReflection | ProjectReflection, tagToRemove: string): void;
/**
 * Removes the given reflection from the given group.
 * @param ref The reflection that should be removed from the group.
 * @param group The group from which the reflection should be removed.
 */
export declare function removeReflectionFromGroup(ref: DeclarationReflection | DocumentReflection, group: ReflectionGroup): void;
/**
 * Adds the given reflection to the given target.
 * @param ref The reflection which should be added to the target.
 * @param target The target to which to add the reflection.
 */
export declare function addReflectionToTarget(ref: DeclarationReflection | DocumentReflection, target: ProjectReflection | DeclarationReflection): void;
/**
 * Removes the given reflection from its parent.
 * @param ref The reflection which should be removed from its parent.
 */
export declare function removeReflectionFromParent(ref: DeclarationReflection | DocumentReflection): void;
/**
 * Moves a reflection to the given target.
 * @param ref The reflection that should be moved.
 * @param target The target into which the reflection should be moved.
 */
export declare function moveReflectionToTarget(ref: DeclarationReflection | DocumentReflection, target: DeclarationReflection | ProjectReflection): void;
/**
 * Returns the modules within the given module parent. Searches recursively.
 * @param moduleParent The element in which to search for modules.
 * @returns The modules within the given module parent.
 */
export declare function getModulesFrom(moduleParent: ProjectReflection | DeclarationReflection): DeclarationReflection[];
/**
 * Returns the name of the given description tag.
 * @param tag The description tag.
 * @returns The name of the given description tag.
 */
export declare function getNameFromDescriptionTag(tag: CommentTag): string;
